@@ -1,6 +1,6 @@
 mod structs;
 mod traits;
 pub use structs::cash::Cash;
-pub use traits::{create::Procedures, calculate::Operations};
+pub use traits::{create::Procedures, calculate::Calculate};
 
 
