@@ -1,13 +1,13 @@
 use crate::structs::cash::Cash;
 
-pub trait Operations {
+pub trait Calculate {
     fn add(&self, amount: i64) -> Self;
     fn subtract(&self, amount: i64) -> Self;
     fn multiply(&self, amount: i64) -> Self;
     fn divide(&self, amount: i64) -> Self;
 }
 
-impl Operations for Cash {
+impl Calculate for Cash {
     fn add(&self, amount: i64) -> Self {
         let new_amount: i64 = &self.amount + amount;
         Self {
