@@ -21,13 +21,4 @@ impl Procedures for Cash {
     fn amount(&self) -> i64 {
         self.amount
     }
-}
-
-impl Cash {
-    pub fn new(currency: &str, amount: i64) -> Self {
-        Self {
-            currency: String::from(currency),
-            amount: amount,
-        }
-    }
 }
\ No newline at end of file
